@@ -77,11 +77,7 @@ Lukk
 d'
 """
 if __name__ == "__main__":
-    import sys
-    sys.path.append(".")
-    sys.path.append("src")
-    import i18n
-    i18n.setup_srcdir()
+    import testsetup
 
 import random
 import _exceptions
