@@ -47,7 +47,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
         self.g_d.queue_draw()
         self.g_pixmap = None
         dim = engravers.dimentions[20]
-        self.set_size_request(-1, numstaff*dim.staff_spacing+dim.first_staff_ypos)
+        self.set_size_request(self.get_size_request()[0], numstaff*dim.staff_spacing+dim.first_staff_ypos)
     def display_range(self, music, fontsize, start, end):
         """Exception handling should be done by the caller."""
         #FIXME this function only handles music where start == Rat(0, 1) correctly
@@ -64,9 +64,9 @@ class MusicDisplayer(gtk.ScrolledWindow):
         """Exception handling should be done by the caller."""
         score = parser.parse_to_score_object(music)
         if what_part == const.ALL:
-           self.m_engravers = score.get_engravers(fontsize)
+            self.m_engravers = score.get_engravers(fontsize)
         elif what_part == const.FIRST:
-           self.m_engravers = score.get_first_engravers(fontsize)
+            self.m_engravers = score.get_first_engravers(fontsize)
 
         self.m_fontsize = fontsize
         self._display()
@@ -74,7 +74,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
         dim = engravers.dimentions[self.m_fontsize]
         self.m_width = self.m_engravers[0][-1].m_xpos + 20
         self.m_height = len(self.m_engravers)*dim.staff_spacing+dim.first_staff_ypos
-        self.set_size_request(-1, self.m_height)
+        self.set_size_request(self.get_size_request()[0], self.m_height)
         self.g_d.set_size_request(self.m_width, self.m_height-4)
         self.g_pixmap = None
         self.g_d.queue_draw()
@@ -114,7 +114,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
                     if isinstance(e, engravers.StemEngraver):
                         e.engrave(darea, self.black_gc, staff_centrum)
                 for y in range(-2, 3):
-                   darea.window.draw_line(self.black_gc,
+                    darea.window.draw_line(self.black_gc,
                                  0, staff_centrum+dim.linespacing*y,
                                  self.m_width, staff_centrum+y*dim.linespacing)
                 staff_centrum = staff_centrum + dim.staff_spacing
