@@ -42,8 +42,13 @@ class MidiFileSynth:
             print "tmpfile:", self.m_tmpfilename
         self.__child_pid = None
     def close(self):
-        if os.path.exists(self.m_tmpfilename):
-            os.remove(self.m_tmpfilename)
+	try:
+            if os.path.exists(self.m_tmpfilename):
+                os.remove(self.m_tmpfilename)
+        except OSError:
+            pass
+	    # We ignore this error because it seems to be easiest right now.
+	    # FIXME
     def join_cmd_and_filename(self, cmd, filename):
         if "%s" in cmd:
             return cmd % filename
