@@ -245,7 +245,7 @@ It is also possible that the OS sound setup is incorrect.
             return
         if urlobj.lessonfile:
             filepath = os.path.join(self.get_string('lessoncollections/%s' % urlobj.lessoncollection), urlobj.lessonfile)
-            if not os.path.isfile(os.path.expanduser(filepath)):
+            if not os.path.isfile(gethomedir.expanduser(filepath)):
                 self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
                 return
         # the Url class does not know anything about lesson ids, so
