@@ -25,6 +25,7 @@ from instrumentselector import nInstrumentSelector, InstrumentConfigurator
 import cfg
 import osutils
 import soundcard
+import languages
 
 def find_wav_player_programs():
     ret = []
@@ -157,6 +158,29 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                 'expert_mode', _("E_xpert mode"))
         self.g_expert_mode.connect('toggled', self.m_app.reset_exercise)
         category_vbox.pack_start(self.g_expert_mode, False)
+        # Combobox to select language
+        hbox = gtk.HBox()
+        hbox.set_spacing(6)
+        label = gtk.Label()
+        label.set_text_with_mnemonic(_("Select _language:"))
+        hbox.pack_start(label, False)
+        self.g_language = gtk.combo_box_new_text()
+        for n in languages.languages:
+            self.g_language.append_text(n)
+        label.set_mnemonic_widget(self.g_language)
+        if cfg.get_string('app/lc_messages') in languages.languages:
+            idx = languages.languages.index(cfg.get_string('app/lc_messages'))
+            self.g_language.set_active(idx)
+        else:
+            self.g_language.set_active(0)
+        def f(combobox):
+            cfg.set_string('app/lc_messages', languages.languages[combobox.get_active()])
+        self.g_language.connect_after('changed', f)
+        hbox.pack_start(self.g_language, False)
+        category_vbox.pack_start(hbox)
+	l = gtk.Label(_("You have to restart the program for the language change to take effect."))
+	l.set_alignment(0.0, 0.5)
+	category_vbox.pack_start(l)
         ############
         # Practise #
         ############
@@ -194,8 +218,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             liststore.append((n,))
         self.g_wav_player = gtk.ComboBoxEntry(liststore)
         self.g_wav_player.child.set_text(cfg.get_string('sound/wav_player'))
-        self.g_wav_player.child.connect('changed',
-            lambda w: self.set_string('sound/wav_player', w.get_text()))
+        self.g_wav_player.connect('changed',
+            lambda w: self.set_string('sound/wav_player', w.child.get_text()))
         button = gtk.Button(_("Test"))
         button.connect('clicked', self.test_wav_player)
         box = gu.hig_label_widget(_(".wav file player"),
@@ -208,8 +232,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             liststore.append((s,))
         self.g_midi_player = gtk.ComboBoxEntry(liststore)
         self.g_midi_player.child.set_text(cfg.get_string('sound/midi_player'))
-        self.g_midi_player.child.connect('changed',
-            lambda w: self.set_string('sound/midi_player', w.get_text()))
+        self.g_midi_player.connect('changed',
+            lambda w: self.set_string('sound/midi_player', w.child.get_text()))
         button = gtk.Button(_("Test"))
         button.connect('clicked', self.test_midi_player)
         box = gu.hig_label_widget(_(".midi file player"),
@@ -283,8 +307,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             liststore.append((s, ))
         self.g_midi_player = gtk.ComboBoxEntry(liststore)
         self.g_midi_player.child.set_text(cfg.get_string('sound/midi_player'))
-        self.g_midi_player.child.connect('changed',
-            lambda w: self.set_string('sound/midi_player', w.get_text()))
+        self.g_midi_player.connect('changed',
+            lambda w: self.set_string('sound/midi_player', w.child.get_text()))
         button = gtk.Button(_("Test"))
         button.connect('clicked', self.test_midi_player)
         box = gu.hig_label_widget(".midi file player",
