@@ -390,4 +390,22 @@ class HarmonicProgressionLabel(gtk.HBox):
         t1.show()
         self.pack_start(t1, False)
 
+def dialog_yesno(text, parent=None):
+    """Return True if the answer is yes, False if the answer is no.
+    """
+    m = gtk.MessageDialog(parent, gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION,
+            gtk.BUTTONS_YES_NO, text)
+    ret = m.run()
+    m.destroy()
+    return ret == gtk.RESPONSE_YES
+
+def dialog_ok(text, parent=None):
+    """"
+    Return the gtk.RESPONSE_XXXX returned by .run()
+    """
+    m = gtk.MessageDialog(parent, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
+            gtk.BUTTONS_OK, text)
+    ret = m.run()
+    m.destroy()
+    return ret
 
