@@ -47,6 +47,9 @@ class LearningTree:
                     del topic['lessons'][topic['lessons'].index(j)]
             if j in self.m_deps:
                 del self.m_deps[j]
+            for d in self.m_deps:
+                if j in self.m_deps[d]:
+                    self.m_deps[d].remove(j)
         self.sort_topics()
         self.calculate_visibilities()
     def save(self, filename):
