@@ -1007,7 +1007,7 @@ class LessonIdParser(object):
         """
         Return True if the file has a header block.
         """
-        return re.search("[^#]\s*header", self.m_file_content) is not None
+        return re.search("^\s*header", self.m_file_content, re.MULTILINE) is not None
     def has_lesson_id(self):
         """
         Return True if the lesson file has a lesson_id.
@@ -1052,7 +1052,7 @@ class LessonIdParser(object):
             self.add_header_block()
         else:
             ofile = file(self.m_filename, 'w')
-            m = re.search("^[^\#]\s*header\s*{", self.m_file_content,
+            m = re.search("^\s*header\s*{", self.m_file_content,
                             re.MULTILINE)
             if m:
                 ofile.write(self.m_file_content[:m.start()])
