@@ -30,7 +30,16 @@ import configureoutput
 
 import optparse
 
-opt_parser = optparse.OptionParser()
+class MyOptionParser(optparse.OptionParser):
+    def print_help(self, file=None):
+        if file is None:
+            file = sys.stdout
+        encoding = file.encoding
+        if not encoding:
+            encoding = "iso-8859-1"
+        file.write(self.format_help().encode(encoding, 'replace'))
+
+opt_parser = MyOptionParser()
 opt_parser.add_option('-v', '--version', action='store_true', dest='version')
 opt_parser.add_option('-w', '--warranty', action='store_true', dest='warranty',
     help=_('Show warranty and copyright.'))
