@@ -23,7 +23,7 @@ if __name__ == '__main__':
     sys.path.append(".")
     sys.path.append("src")
     import i18n
-    i18n.setup_srcdir()
+    i18n.setup(".")
 
 import gtk, gobject
 import mpd, gu, cfg
