@@ -29,6 +29,7 @@ import os
 _has_gtkhtml2 = None
 _has_gnome_canvas = None
 _has_gnome = None
+use_cairo_widgets = None
 
 def assert_python_version(required_version):
     if sys.version_info < required_version:
@@ -59,6 +60,8 @@ def setup_pygtk(required_version):
 def init(options):
     global _has_gtkhtml2
     global _has_gnome
+    global _has_gnome_canvas
+    global use_cairo_widgets
     assert_python_version((2, 3))
     setup_pygtk((2, 4))
     if options.without_gtkhtml:
@@ -66,7 +69,16 @@ def init(options):
         print "gtkhtml2: disabled by runtime option"
     if options.without_gnome:
         _has_gnome = False
+        _has_gnome_canvas = False
         print "gnome: disabled by runtime option"
+    if options.no_cairo_widgets:
+        use_cairo_widgets = False
+    else:
+        import gtk
+        if gtk.pygtk_version < (2, 8, 0):
+            use_cairo_widgets = False
+        else:
+            use_cairo_widgets = True
 
 
 
